==> geodesign-0.01.tar.gz: geodesign-0.01/setup.py <==
from distutils.core import setup
setup(
  name = 'geodesign',         # How you named your package folder (MyLib)
  packages = ['geodesign'],   # Chose the same as "name"
  version = '0.01',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Geospatial Data Sciene on Experimental Design',   # Give a short description about your library
  long_description = "Geospatial data analytics on experimental treatment design and analysis of the treatment i.e. Latin Square, RCBD etc.",
  author = 'Abir Raihan',                   # Type in your name
  author_email = 'abirraihan.urp@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/abiraihan/geodesign',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/abiraihan/geodesign/archive/0.1.tar.gz',    # I explain this later on
  keywords = ['Experimental Design', 'Geospatial Data Science', 'Spatial Analytics'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'time',
          'math',
          'glob',
          'shapely',
          'pandas',
          'geopandas',
          'tqdm',
          'PySimpleGUI',
          'warnings',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
  ],
)

==> geodesign-0.02.tar.gz: geodesign-0.02/setup.py <==
from distutils.core import setup
setup(
  name = 'geodesign',         # How you named your package folder (MyLib)
  packages = ['geodesign'],   # Chose the same as "name"
  version = '0.02',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Geospatial Data Sciene on Experimental Design',   # Give a short description about your library
  author = 'Abir Raihan',                   # Type in your name
  author_email = 'abirraihan.urp@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/abirraihan/geodesign',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/abiraihan/geodesign/archive/0.1.tar.gz',    # I explain this later on
  keywords = ['Experimental Design', 'Spatial Analysis Tool'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'glob',
          'shapely',
          'pandas',
          'geopandas',
          'tqdm',
          'PySimpleGUI',
          'warnings',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
  ],
)
